# The safedata_validator package

[![codecov](https://codecov.io/gh/ImperialCollegeLondon/safedata_validator/branch/develop/graph/badge.svg)](https://codecov.io/gh/ImperialCollegeLondon/safedata_validator)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/ImperialCollegeLondon/safedata_validator/develop.svg)](https://results.pre-commit.ci/latest/github/ImperialCollegeLondon/safedata_validator/develop)

This package provides methods to validate XLSX files containing formatted data and
metadata using the SAFE Project data format.

See the main documentation for a detailed description and usage:

> [https://safedata-validator.readthedocs.io](https://safedata-validator.readthedocs.io)

## Development notes

Detailed notes for those interested in assisting with development of the package can be
found [here](docs/developers/package_development.md).
